import logging
import os

import rasax.community.initialise as initialise
import rasax.community.sql_migrations as sql_migrations
from rasax.community import config
from rasax.community.api.app import configure_app, initialize_app
from rasax.community.database.utils import session_scope
from rasax.community.services.model_service import ModelService
from rasax.community.services.settings_service import SettingsService
import rasax.community.utils as rasax_utils

logger = logging.getLogger(__name__)


def main():
    app = configure_app()
    initialize_app(app)
    with session_scope() as session:
        sql_migrations.run_migrations(session)
        initialise.create_community_user(session, app)

        # Initialize environments before they are used in the model discovery process
        settings_service = SettingsService(session)
        settings_service.inject_environments_config_from_file(
            config.project_name, config.default_environments_config_path
        )

        model_service = ModelService(config.rasa_model_dir, session, "production")
        model_service.discover_models_on_init()
        model_service.mark_latest_as_production()

    rasax_utils.update_log_level()

    app.run(
        host="0.0.0.0",
        port=config.self_port,
        auto_reload=os.environ.get("SANIC_AUTO_RELOAD"),
        workers=4,
    )


if __name__ == "__main__":
    from rasax.community.services.event_service import main as event_service_main
    import rasax.community.services.notification_service as notifications

    rasax_utils.update_log_level()

    # launch event service as background process
    logger.debug("Starting event service.")
    rasax_utils.run_in_process(event_service_main)

    rasax_utils.run_in_process(notifications.run_websocket_server)

    logger.debug("Starting API service.")
    # start API
    main()
